@@ -23,6 +23,7 @@ from .type_defs import (
     AttributeTypeDef,
     DeletableItemTypeDef,
     DomainMetadataResultTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetAttributesResultTypeDef,
     ListDomainsResultTypeDef,
     ReplaceableAttributeTypeDef,
@@ -87,8 +88,8 @@ class SimpleDBClient(BaseClient):
         """
 
     def batch_delete_attributes(
-        self, *, DomainName: str, Items: Sequence["DeletableItemTypeDef"]
-    ) -> None:
+        self, *, DomainName: str, Items: Sequence[DeletableItemTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Performs multiple DeleteAttributes operations in a single call, which reduces
         round trips and latencies.
@@ -98,8 +99,8 @@ class SimpleDBClient(BaseClient):
         """
 
     def batch_put_attributes(
-        self, *, DomainName: str, Items: Sequence["ReplaceableItemTypeDef"]
-    ) -> None:
+        self, *, DomainName: str, Items: Sequence[ReplaceableItemTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         The `BatchPutAttributes` operation creates or replaces attributes within one or
         more items.
@@ -116,7 +117,15 @@ class SimpleDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sdb/client/#can_paginate)
         """
 
-    def create_domain(self, *, DomainName: str) -> None:
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sdb.html#SimpleDB.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sdb/client/#close)
+        """
+
+    def create_domain(self, *, DomainName: str) -> EmptyResponseMetadataTypeDef:
         """
         The `CreateDomain` operation creates a new domain.
 
@@ -129,9 +138,9 @@ class SimpleDBClient(BaseClient):
         *,
         DomainName: str,
         ItemName: str,
-        Attributes: Sequence["AttributeTypeDef"] = ...,
-        Expected: "UpdateConditionTypeDef" = ...
-    ) -> None:
+        Attributes: Sequence[AttributeTypeDef] = ...,
+        Expected: UpdateConditionTypeDef = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes one or more attributes associated with an item.
 
@@ -139,7 +148,7 @@ class SimpleDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sdb/client/#delete_attributes)
         """
 
-    def delete_domain(self, *, DomainName: str) -> None:
+    def delete_domain(self, *, DomainName: str) -> EmptyResponseMetadataTypeDef:
         """
         The `DeleteDomain` operation deletes a domain.
 
@@ -201,9 +210,9 @@ class SimpleDBClient(BaseClient):
         *,
         DomainName: str,
         ItemName: str,
-        Attributes: Sequence["ReplaceableAttributeTypeDef"],
-        Expected: "UpdateConditionTypeDef" = ...
-    ) -> None:
+        Attributes: Sequence[ReplaceableAttributeTypeDef],
+        Expected: UpdateConditionTypeDef = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         The PutAttributes operation creates or replaces attributes in an item.
 
