@@ -22,29 +22,30 @@ else:
 
 __all__ = (
     "AttributeTypeDef",
-    "BatchDeleteAttributesRequestRequestTypeDef",
-    "BatchPutAttributesRequestRequestTypeDef",
     "CreateDomainRequestRequestTypeDef",
-    "DeletableItemTypeDef",
-    "DeleteAttributesRequestRequestTypeDef",
+    "UpdateConditionTypeDef",
     "DeleteDomainRequestRequestTypeDef",
     "DomainMetadataRequestRequestTypeDef",
-    "DomainMetadataResultTypeDef",
-    "GetAttributesRequestRequestTypeDef",
-    "GetAttributesResultTypeDef",
-    "ItemTypeDef",
-    "ListDomainsRequestListDomainsPaginateTypeDef",
-    "ListDomainsRequestRequestTypeDef",
-    "ListDomainsResultTypeDef",
-    "PaginatorConfigTypeDef",
-    "PutAttributesRequestRequestTypeDef",
-    "ReplaceableAttributeTypeDef",
-    "ReplaceableItemTypeDef",
     "ResponseMetadataTypeDef",
+    "GetAttributesRequestRequestTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListDomainsRequestRequestTypeDef",
+    "ReplaceableAttributeTypeDef",
     "SelectRequestRequestTypeDef",
+    "DeletableItemTypeDef",
+    "ItemTypeDef",
+    "DeleteAttributesRequestRequestTypeDef",
+    "DomainMetadataResultTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "GetAttributesResultTypeDef",
+    "ListDomainsResultTypeDef",
+    "ListDomainsRequestListDomainsPaginateTypeDef",
     "SelectRequestSelectPaginateTypeDef",
+    "PutAttributesRequestRequestTypeDef",
+    "ReplaceableItemTypeDef",
+    "BatchDeleteAttributesRequestRequestTypeDef",
     "SelectResultTypeDef",
-    "UpdateConditionTypeDef",
+    "BatchPutAttributesRequestRequestTypeDef",
 )
 
 _RequiredAttributeTypeDef = TypedDict(
@@ -68,22 +69,6 @@ class AttributeTypeDef(_RequiredAttributeTypeDef, _OptionalAttributeTypeDef):
     pass
 
 
-BatchDeleteAttributesRequestRequestTypeDef = TypedDict(
-    "BatchDeleteAttributesRequestRequestTypeDef",
-    {
-        "DomainName": str,
-        "Items": Sequence["DeletableItemTypeDef"],
-    },
-)
-
-BatchPutAttributesRequestRequestTypeDef = TypedDict(
-    "BatchPutAttributesRequestRequestTypeDef",
-    {
-        "DomainName": str,
-        "Items": Sequence["ReplaceableItemTypeDef"],
-    },
-)
-
 CreateDomainRequestRequestTypeDef = TypedDict(
     "CreateDomainRequestRequestTypeDef",
     {
@@ -91,48 +76,16 @@ CreateDomainRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDeletableItemTypeDef = TypedDict(
-    "_RequiredDeletableItemTypeDef",
+UpdateConditionTypeDef = TypedDict(
+    "UpdateConditionTypeDef",
     {
         "Name": str,
-    },
-)
-_OptionalDeletableItemTypeDef = TypedDict(
-    "_OptionalDeletableItemTypeDef",
-    {
-        "Attributes": Sequence["AttributeTypeDef"],
+        "Value": str,
+        "Exists": bool,
     },
     total=False,
 )
 
-
-class DeletableItemTypeDef(_RequiredDeletableItemTypeDef, _OptionalDeletableItemTypeDef):
-    pass
-
-
-_RequiredDeleteAttributesRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteAttributesRequestRequestTypeDef",
-    {
-        "DomainName": str,
-        "ItemName": str,
-    },
-)
-_OptionalDeleteAttributesRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteAttributesRequestRequestTypeDef",
-    {
-        "Attributes": Sequence["AttributeTypeDef"],
-        "Expected": "UpdateConditionTypeDef",
-    },
-    total=False,
-)
-
-
-class DeleteAttributesRequestRequestTypeDef(
-    _RequiredDeleteAttributesRequestRequestTypeDef, _OptionalDeleteAttributesRequestRequestTypeDef
-):
-    pass
-
-
 DeleteDomainRequestRequestTypeDef = TypedDict(
     "DeleteDomainRequestRequestTypeDef",
     {
@@ -147,17 +100,14 @@ DomainMetadataRequestRequestTypeDef = TypedDict(
     },
 )
 
-DomainMetadataResultTypeDef = TypedDict(
-    "DomainMetadataResultTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "ItemCount": int,
-        "ItemNamesSizeBytes": int,
-        "AttributeNameCount": int,
-        "AttributeNamesSizeBytes": int,
-        "AttributeValueCount": int,
-        "AttributeValuesSizeBytes": int,
-        "Timestamp": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -184,38 +134,12 @@ class GetAttributesRequestRequestTypeDef(
     pass
 
 
-GetAttributesResultTypeDef = TypedDict(
-    "GetAttributesResultTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "Attributes": List["AttributeTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredItemTypeDef = TypedDict(
-    "_RequiredItemTypeDef",
-    {
-        "Name": str,
-        "Attributes": List["AttributeTypeDef"],
-    },
-)
-_OptionalItemTypeDef = TypedDict(
-    "_OptionalItemTypeDef",
-    {
-        "AlternateNameEncoding": str,
-    },
-    total=False,
-)
-
-
-class ItemTypeDef(_RequiredItemTypeDef, _OptionalItemTypeDef):
-    pass
-
-
-ListDomainsRequestListDomainsPaginateTypeDef = TypedDict(
-    "ListDomainsRequestListDomainsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
@@ -229,48 +153,6 @@ ListDomainsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListDomainsResultTypeDef = TypedDict(
-    "ListDomainsResultTypeDef",
-    {
-        "DomainNames": List[str],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-_RequiredPutAttributesRequestRequestTypeDef = TypedDict(
-    "_RequiredPutAttributesRequestRequestTypeDef",
-    {
-        "DomainName": str,
-        "ItemName": str,
-        "Attributes": Sequence["ReplaceableAttributeTypeDef"],
-    },
-)
-_OptionalPutAttributesRequestRequestTypeDef = TypedDict(
-    "_OptionalPutAttributesRequestRequestTypeDef",
-    {
-        "Expected": "UpdateConditionTypeDef",
-    },
-    total=False,
-)
-
-
-class PutAttributesRequestRequestTypeDef(
-    _RequiredPutAttributesRequestRequestTypeDef, _OptionalPutAttributesRequestRequestTypeDef
-):
-    pass
-
-
 _RequiredReplaceableAttributeTypeDef = TypedDict(
     "_RequiredReplaceableAttributeTypeDef",
     {
@@ -293,25 +175,6 @@ class ReplaceableAttributeTypeDef(
     pass
 
 
-ReplaceableItemTypeDef = TypedDict(
-    "ReplaceableItemTypeDef",
-    {
-        "Name": str,
-        "Attributes": Sequence["ReplaceableAttributeTypeDef"],
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 _RequiredSelectRequestRequestTypeDef = TypedDict(
     "_RequiredSelectRequestRequestTypeDef",
     {
@@ -334,6 +197,114 @@ class SelectRequestRequestTypeDef(
     pass
 
 
+_RequiredDeletableItemTypeDef = TypedDict(
+    "_RequiredDeletableItemTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalDeletableItemTypeDef = TypedDict(
+    "_OptionalDeletableItemTypeDef",
+    {
+        "Attributes": Sequence[AttributeTypeDef],
+    },
+    total=False,
+)
+
+
+class DeletableItemTypeDef(_RequiredDeletableItemTypeDef, _OptionalDeletableItemTypeDef):
+    pass
+
+
+_RequiredItemTypeDef = TypedDict(
+    "_RequiredItemTypeDef",
+    {
+        "Name": str,
+        "Attributes": List[AttributeTypeDef],
+    },
+)
+_OptionalItemTypeDef = TypedDict(
+    "_OptionalItemTypeDef",
+    {
+        "AlternateNameEncoding": str,
+    },
+    total=False,
+)
+
+
+class ItemTypeDef(_RequiredItemTypeDef, _OptionalItemTypeDef):
+    pass
+
+
+_RequiredDeleteAttributesRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteAttributesRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "ItemName": str,
+    },
+)
+_OptionalDeleteAttributesRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteAttributesRequestRequestTypeDef",
+    {
+        "Attributes": Sequence[AttributeTypeDef],
+        "Expected": UpdateConditionTypeDef,
+    },
+    total=False,
+)
+
+
+class DeleteAttributesRequestRequestTypeDef(
+    _RequiredDeleteAttributesRequestRequestTypeDef, _OptionalDeleteAttributesRequestRequestTypeDef
+):
+    pass
+
+
+DomainMetadataResultTypeDef = TypedDict(
+    "DomainMetadataResultTypeDef",
+    {
+        "ItemCount": int,
+        "ItemNamesSizeBytes": int,
+        "AttributeNameCount": int,
+        "AttributeNamesSizeBytes": int,
+        "AttributeValueCount": int,
+        "AttributeValuesSizeBytes": int,
+        "Timestamp": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetAttributesResultTypeDef = TypedDict(
+    "GetAttributesResultTypeDef",
+    {
+        "Attributes": List[AttributeTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListDomainsResultTypeDef = TypedDict(
+    "ListDomainsResultTypeDef",
+    {
+        "DomainNames": List[str],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListDomainsRequestListDomainsPaginateTypeDef = TypedDict(
+    "ListDomainsRequestListDomainsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 _RequiredSelectRequestSelectPaginateTypeDef = TypedDict(
     "_RequiredSelectRequestSelectPaginateTypeDef",
     {
@@ -344,7 +315,7 @@ _OptionalSelectRequestSelectPaginateTypeDef = TypedDict(
     "_OptionalSelectRequestSelectPaginateTypeDef",
     {
         "ConsistentRead": bool,
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
 )
@@ -356,21 +327,58 @@ class SelectRequestSelectPaginateTypeDef(
     pass
 
 
-SelectResultTypeDef = TypedDict(
-    "SelectResultTypeDef",
+_RequiredPutAttributesRequestRequestTypeDef = TypedDict(
+    "_RequiredPutAttributesRequestRequestTypeDef",
     {
-        "Items": List["ItemTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "DomainName": str,
+        "ItemName": str,
+        "Attributes": Sequence[ReplaceableAttributeTypeDef],
     },
 )
-
-UpdateConditionTypeDef = TypedDict(
-    "UpdateConditionTypeDef",
+_OptionalPutAttributesRequestRequestTypeDef = TypedDict(
+    "_OptionalPutAttributesRequestRequestTypeDef",
     {
-        "Name": str,
-        "Value": str,
-        "Exists": bool,
+        "Expected": UpdateConditionTypeDef,
     },
     total=False,
 )
+
+
+class PutAttributesRequestRequestTypeDef(
+    _RequiredPutAttributesRequestRequestTypeDef, _OptionalPutAttributesRequestRequestTypeDef
+):
+    pass
+
+
+ReplaceableItemTypeDef = TypedDict(
+    "ReplaceableItemTypeDef",
+    {
+        "Name": str,
+        "Attributes": Sequence[ReplaceableAttributeTypeDef],
+    },
+)
+
+BatchDeleteAttributesRequestRequestTypeDef = TypedDict(
+    "BatchDeleteAttributesRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "Items": Sequence[DeletableItemTypeDef],
+    },
+)
+
+SelectResultTypeDef = TypedDict(
+    "SelectResultTypeDef",
+    {
+        "Items": List[ItemTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+BatchPutAttributesRequestRequestTypeDef = TypedDict(
+    "BatchPutAttributesRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "Items": Sequence[ReplaceableItemTypeDef],
+    },
+)
